package cn.newfeifan.mall.module.distri.controller.admin.socialstatuschangecategory;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.newfeifan.mall.framework.common.pojo.PageParam;
import cn.newfeifan.mall.framework.common.pojo.PageResult;
import cn.newfeifan.mall.framework.common.pojo.CommonResult;
import cn.newfeifan.mall.framework.common.util.object.BeanUtils;
import static cn.newfeifan.mall.framework.common.pojo.CommonResult.success;

import cn.newfeifan.mall.framework.excel.core.util.ExcelUtils;

import cn.newfeifan.mall.framework.operatelog.core.annotations.OperateLog;
import static cn.newfeifan.mall.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.newfeifan.mall.module.distri.controller.admin.socialstatuschangecategory.vo.*;
import cn.newfeifan.mall.module.distri.dal.dataobject.socialstatuschangecategory.SocialStatusChangeCategoryDO;
import cn.newfeifan.mall.module.distri.service.socialstatuschangecategory.SocialStatusChangeCategoryService;

@Tag(name = "管理后台 - 会员身价变化类别")
@RestController
@RequestMapping("/distri/social-status-change-category")
@Validated
public class SocialStatusChangeCategoryController {

    @Resource
    private SocialStatusChangeCategoryService socialStatusChangeCategoryService;

    @PostMapping("/create")
    @Operation(summary = "创建会员身价变化类别")
    @PreAuthorize("@ss.hasPermission('distri:social-status-change-category:create')")
    public CommonResult<Long> createSocialStatusChangeCategory(@Valid @RequestBody SocialStatusChangeCategorySaveReqVO createReqVO) {
        return success(socialStatusChangeCategoryService.createSocialStatusChangeCategory(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新会员身价变化类别")
    @PreAuthorize("@ss.hasPermission('distri:social-status-change-category:update')")
    public CommonResult<Boolean> updateSocialStatusChangeCategory(@Valid @RequestBody SocialStatusChangeCategorySaveReqVO updateReqVO) {
        socialStatusChangeCategoryService.updateSocialStatusChangeCategory(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除会员身价变化类别")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('distri:social-status-change-category:delete')")
    public CommonResult<Boolean> deleteSocialStatusChangeCategory(@RequestParam("id") Long id) {
        socialStatusChangeCategoryService.deleteSocialStatusChangeCategory(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得会员身价变化类别")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('distri:social-status-change-category:query')")
    public CommonResult<SocialStatusChangeCategoryRespVO> getSocialStatusChangeCategory(@RequestParam("id") Long id) {
        SocialStatusChangeCategoryDO socialStatusChangeCategory = socialStatusChangeCategoryService.getSocialStatusChangeCategory(id);
        return success(BeanUtils.toBean(socialStatusChangeCategory, SocialStatusChangeCategoryRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得会员身价变化类别分页")
    @PreAuthorize("@ss.hasPermission('distri:social-status-change-category:query')")
    public CommonResult<PageResult<SocialStatusChangeCategoryRespVO>> getSocialStatusChangeCategoryPage(@Valid SocialStatusChangeCategoryPageReqVO pageReqVO) {
        PageResult<SocialStatusChangeCategoryDO> pageResult = socialStatusChangeCategoryService.getSocialStatusChangeCategoryPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, SocialStatusChangeCategoryRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出会员身价变化类别 Excel")
    @PreAuthorize("@ss.hasPermission('distri:social-status-change-category:export')")
    @OperateLog(type = EXPORT)
    public void exportSocialStatusChangeCategoryExcel(@Valid SocialStatusChangeCategoryPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<SocialStatusChangeCategoryDO> list = socialStatusChangeCategoryService.getSocialStatusChangeCategoryPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "会员身价变化类别.xls", "数据", SocialStatusChangeCategoryRespVO.class,
                        BeanUtils.toBean(list, SocialStatusChangeCategoryRespVO.class));
    }

}